==> bitcoin-23.1.tar.gz: bitcoin-23.1/src/qt/locale/bitcoin_ku.ts <==
<TS version="2.1" language="ku">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Nû</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kopi bike</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">Bigire</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Navnîşana hilbijartî ji lîsteyê jê bibe</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Ji bo lêgerînê navnîşan an jî etîketê têkeve</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Daneya di hilpekîna niha de bi rêya dosyayekê derxîne</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Derxîne</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Jê bibe</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Navnîşana ku ew ê koîn werin şandin, hilbijêre</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Navnîşana ku ew ê koînan bistîne, hilbijêre</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">H&amp;ilbijêre</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">Navnîşanên şandinê</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">Navnîşanên stendinê</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Navnîşanê kopî bike</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Etîketê &amp;kopî bike</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Serrast bike</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Lîsteya navnîşanan derxîne</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etîket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Navnîşan</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etîket tune)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Pêborîna xwe têkevê</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Pêborîna nû</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Pêborîna xwe ya nû dubare bike</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Pêborînê nîşan bide</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Şîfrekirina cizdên</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Kilîda cizdên veke</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Pêborînê biguherîne</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Şîfrekirina cizdên bipejirîne</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Tu bi rastî jî dixwazî cizdanê xwe şîfre bikî?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Cizdan hate şîfrekirin</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Cizdan:</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Agahî</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarîx</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etîket tune)</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Navnîşan</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">Cure</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Cizdan:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarîx</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etîket</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etîket tune)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etîket tune)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarîx</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarîx</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Cure</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etîket</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etîket tune)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarîx</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Cure</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etîket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Navnîşan</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">Derxîne</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Daneya di hilpekîna niha de bi rêya dosyayekê derxîne</translation>
    </message>
    </context>
</TS>

==> bitcoin-25.0rc1.tar.gz: bitcoin-25.0rc1/src/qt/locale/bitcoin_ku.ts <==
<TS version="2.1" language="ku">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Nû</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kopi bike</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">Bigire</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Navnîşana hilbijartî ji lîsteyê rake</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Ji bo lêgerînê navnîşan an jî etîketê têkeve</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Daneya di hilpekîna niha de bi rêya dosyayekê derxîne</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">Derxîne</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">Jê bibe</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Navnîşana ku ew ê koîn were şandin, hilbijêre</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Navnîşana ku ew ê koînan bistîne, hilbijêre</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">H&amp;ilbijêre</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">Navnîşanên şandinê</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">Navnîşanên stendinê</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Navnîşanê kopî bike</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Etîketê &amp;kopî bike</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Serrast bike</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Lîsteya navnîşanan derxîne</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etîket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Navnîşan</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etîket tune)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Pêborîna xwe têkevê</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Pêborîna nû</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Pêborîna xwe ya nû dubare bike</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Pêborînê nîşan bide</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Şîfrekirina cizdên</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Kilîda cizdên veke</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Pêborînê biguherîne</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Şîfrekirina cizdên bipejirîne</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Tu bi rastî jî dixwazî cizdanê xwe şîfre bikî?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Cizdan hate şîfrekirin</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Cizdan:</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Agahî</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarîx</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etîket tune)</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Navnîşan</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">Cure</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Cizdan:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarîx</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etîket</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etîket tune)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etîket tune)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarîx</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarîx</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Cure</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etîket</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etîket tune)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarîx</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Cure</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etîket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Navnîşan</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">Derxîne</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Daneya di hilpekîna niha de bi rêya dosyayekê derxîne</translation>
    </message>
    </context>
</TS>
